@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
@@ -73,7 +73,7 @@ zenity_calendar (ZenityData *data, ZenityCalendarData *cal_data)
   if (glade_dialog)
     g_object_unref (glade_dialog);
 
-  if (cal_data->month > 0 && cal_data->year > 0)
+  if (cal_data->month > 0 || cal_data->year > 0)
     gtk_calendar_select_month (GTK_CALENDAR (calendar), cal_data->month - 1, cal_data->year);
   if (cal_data->day > 0)
     gtk_calendar_select_day (GTK_CALENDAR (calendar), cal_data->day);
