@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
@@ -64,7 +64,10 @@ void zenity_fileselection (ZenityData *data, ZenityFileData *file_data)
 
   if (file_data->uri) {
     dir = g_path_get_dirname (file_data->uri);
-    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), dir);
+
+    if (g_path_is_absolute (file_data->uri) == TRUE)
+      gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), dir);
+
     if (file_data->uri[strlen (file_data->uri) - 1] != '/') {
       basename = g_path_get_basename (file_data->uri);
       gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), basename);
