@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
@@ -83,29 +83,25 @@ zenity_msg (ZenityData *data, ZenityMsgData *msg_data)
   if (data->dialog_title)
     gtk_window_set_title (GTK_WINDOW (dialog), data->dialog_title);
 
-  if (data->window_icon)
-    zenity_util_set_window_icon (dialog, data->window_icon);
-  else {
-    switch (msg_data->mode) {
-      case ZENITY_MSG_WARNING:
-        zenity_util_set_window_icon_from_stock (dialog, GTK_STOCK_DIALOG_WARNING);
-        break;
+  switch (msg_data->mode) {
+    case ZENITY_MSG_WARNING:
+      zenity_util_set_window_icon_from_stock (dialog, data->window_icon, GTK_STOCK_DIALOG_WARNING);
+      break;
 
-      case ZENITY_MSG_QUESTION:
-        zenity_util_set_window_icon_from_stock (dialog, GTK_STOCK_DIALOG_QUESTION);
-        break;
+    case ZENITY_MSG_QUESTION:
+      zenity_util_set_window_icon_from_stock (dialog, data->window_icon, GTK_STOCK_DIALOG_QUESTION);
+      break;
       
-      case ZENITY_MSG_ERROR:
-        zenity_util_set_window_icon_from_stock (dialog, GTK_STOCK_DIALOG_ERROR);
-        break;
+    case ZENITY_MSG_ERROR:
+      zenity_util_set_window_icon_from_stock (dialog, data->window_icon, GTK_STOCK_DIALOG_ERROR);
+      break;
       
-      case ZENITY_MSG_INFO:
-        zenity_util_set_window_icon_from_stock (dialog, GTK_STOCK_DIALOG_INFO);
-        break;
+    case ZENITY_MSG_INFO:
+      zenity_util_set_window_icon_from_stock (dialog, data->window_icon, GTK_STOCK_DIALOG_INFO);
+      break;
   
-      default:
-        break;
-    }
+    default:
+      break;
   }
   
   if (data->width > -1 || data->height > -1)
@@ -114,6 +110,9 @@ zenity_msg (ZenityData *data, ZenityMsgData *msg_data)
   if (msg_data->dialog_text)
     gtk_label_set_markup (GTK_LABEL (text), msg_data->dialog_text);
 
+  if (msg_data->no_wrap)
+    gtk_label_set_line_wrap (GTK_LABEL (text), FALSE);
+
   zenity_util_show_dialog (dialog);
   gtk_main ();
 }
@@ -126,16 +125,15 @@ zenity_msg_dialog_response (GtkWidget *widget, int response, gpointer data)
   switch (response) {
     case GTK_RESPONSE_OK:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
-      gtk_main_quit ();
       break;
 
     case GTK_RESPONSE_CANCEL:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_CANCEL);
-      gtk_main_quit ();
       break;
 
     default:
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
+  gtk_main_quit ();
 }
